@@ -23,13 +23,13 @@ from airflow.providers.google.cloud.operators.life_sciences import LifeSciencesR
 from airflow.utils import dates
 
 PROJECT_ID = os.environ.get("GCP_PROJECT_ID", "example-project-id")
-BUCKET = os.environ.get("GCP_GCS_LIFE_SCIENCES_BUCKET", "example-life-sciences-bucket")
+BUCKET = os.environ.get("GCP_GCS_LIFE_SCIENCES_BUCKET", "INVALID BUCKET NAME")
 FILENAME = os.environ.get("GCP_GCS_LIFE_SCIENCES_FILENAME", 'input.in')
 LOCATION = os.environ.get("GCP_LIFE_SCIENCES_LOCATION", 'us-central1')
 
 
 # [START howto_configure_simple_action_pipeline]
-SIMPLE_ACTION_PIEPELINE = {
+SIMPLE_ACTION_PIPELINE = {
     "pipeline": {
         "actions": [
             {"imageUri": "bash", "commands": ["-c", "echo Hello, world"]},
@@ -83,7 +83,7 @@ with models.DAG(
     # [START howto_run_pipeline]
     simple_life_science_action_pipeline = LifeSciencesRunPipelineOperator(
         task_id='simple-action-pipeline',
-        body=SIMPLE_ACTION_PIEPELINE,
+        body=SIMPLE_ACTION_PIPELINE,
         project_id=PROJECT_ID,
         location=LOCATION,
     )
