@@ -44,7 +44,7 @@ document = Document(content=TEXT, type="PLAIN_TEXT")
 # [END howto_operator_gcp_natural_language_document_text]
 
 # [START howto_operator_gcp_natural_language_document_gcs]
-GCS_CONTENT_URI = "gs://my-text-bucket/sentiment-me.txt"
+GCS_CONTENT_URI = "gs://INVALID BUCKET NAME/sentiment-me.txt"
 document_gcs = Document(gcs_content_uri=GCS_CONTENT_URI, type="PLAIN_TEXT")
 # [END howto_operator_gcp_natural_language_document_gcs]
 
@@ -63,7 +63,7 @@ with models.DAG(
 
     # [START howto_operator_gcp_natural_language_analyze_entities_result]
     analyze_entities_result = BashOperator(
-        bash_command="echo \"{{ task_instance.xcom_pull('analyze_entities') }}\"",
+        bash_command=f"echo {analyze_entities.output}",
         task_id="analyze_entities_result",
     )
     # [END howto_operator_gcp_natural_language_analyze_entities_result]
@@ -76,7 +76,7 @@ with models.DAG(
 
     # [START howto_operator_gcp_natural_language_analyze_entity_sentiment_result]
     analyze_entity_sentiment_result = BashOperator(
-        bash_command="echo \"{{ task_instance.xcom_pull('analyze_entity_sentiment') }}\"",
+        bash_command=f"echo {analyze_entity_sentiment.output}",
         task_id="analyze_entity_sentiment_result",
     )
     # [END howto_operator_gcp_natural_language_analyze_entity_sentiment_result]
@@ -89,7 +89,7 @@ with models.DAG(
 
     # [START howto_operator_gcp_natural_language_analyze_sentiment_result]
     analyze_sentiment_result = BashOperator(
-        bash_command="echo \"{{ task_instance.xcom_pull('analyze_sentiment') }}\"",
+        bash_command=f"echo {analyze_sentiment.output}",
         task_id="analyze_sentiment_result",
     )
     # [END howto_operator_gcp_natural_language_analyze_sentiment_result]
@@ -102,7 +102,7 @@ with models.DAG(
 
     # [START howto_operator_gcp_natural_language_analyze_classify_text_result]
     analyze_classify_text_result = BashOperator(
-        bash_command="echo \"{{ task_instance.xcom_pull('analyze_classify_text') }}\"",
+        bash_command=f"echo {analyze_classify_text.output}",
         task_id="analyze_classify_text_result",
     )
     # [END howto_operator_gcp_natural_language_analyze_classify_text_result]
