@@ -31,7 +31,6 @@ from airflow.providers.google.cloud.hooks.dataflow import (
     process_line_and_extract_dataflow_job_id_callback,
 )
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
-from airflow.utils.decorators import apply_defaults
 from airflow.version import version
 
 
@@ -53,7 +52,7 @@ class DataflowConfiguration:
     :py:class:`~airflow.providers.apache.beam.operators.beam.BeamRunJavaPipelineOperator` and
     :py:class:`~airflow.providers.apache.beam.operators.beam.BeamRunPythonPipelineOperator`.
 
-    :param job_name: The 'jobName' to use when executing the DataFlow job
+    :param job_name: The 'jobName' to use when executing the Dataflow job
         (templated). This ends up being set in the pipeline options, so any entry
         with key ``'jobName'`` or  ``'job_name'``in ``options`` will be overwritten.
     :type job_name: str
@@ -84,7 +83,7 @@ class DataflowConfiguration:
         account from the list granting this role to the originating account (templated).
     :type impersonation_chain: Union[str, Sequence[str]]
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
-        instead of canceling during during killing task instance. See:
+        instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
     :type drain_pipeline: bool
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
@@ -170,10 +169,9 @@ class DataflowConfiguration:
         self.check_if_running = check_if_running
 
 
-# pylint: disable=too-many-instance-attributes
 class DataflowCreateJavaJobOperator(BaseOperator):
     """
-    Start a Java Cloud DataFlow batch job. The parameters of the operation
+    Start a Java Cloud Dataflow batch job. The parameters of the operation
     will be passed to the job.
 
     This class is deprecated.
@@ -182,36 +180,36 @@ class DataflowCreateJavaJobOperator(BaseOperator):
     **Example**: ::
 
         default_args = {
-            'owner': 'airflow',
-            'depends_on_past': False,
-            'start_date':
-                (2016, 8, 1),
-            'email': ['alex@vanboxel.be'],
-            'email_on_failure': False,
-            'email_on_retry': False,
-            'retries': 1,
-            'retry_delay': timedelta(minutes=30),
-            'dataflow_default_options': {
-                'project': 'my-gcp-project',
-                'zone': 'us-central1-f',
-                'stagingLocation': 'gs://bucket/tmp/dataflow/staging/',
-            }
+            "owner": "airflow",
+            "depends_on_past": False,
+            "start_date": (2016, 8, 1),
+            "email": ["alex@vanboxel.be"],
+            "email_on_failure": False,
+            "email_on_retry": False,
+            "retries": 1,
+            "retry_delay": timedelta(minutes=30),
+            "dataflow_default_options": {
+                "project": "my-gcp-project",
+                "zone": "us-central1-f",
+                "stagingLocation": "gs://bucket/tmp/dataflow/staging/",
+            },
         }
 
-        dag = DAG('test-dag', default_args=default_args)
+        dag = DAG("test-dag", default_args=default_args)
 
-        task = DataFlowJavaOperator(
-            gcp_conn_id='gcp_default',
-            task_id='normalize-cal',
-            jar='{{var.value.gcp_dataflow_base}}pipeline-ingress-cal-normalize-1.0.jar',
+        task = DataflowCreateJavaJobOperator(
+            gcp_conn_id="gcp_default",
+            task_id="normalize-cal",
+            jar="{{var.value.gcp_dataflow_base}}pipeline-ingress-cal-normalize-1.0.jar",
             options={
-                'autoscalingAlgorithm': 'BASIC',
-                'maxNumWorkers': '50',
-                'start': '{{ds}}',
-                'partitionType': 'DAY'
-
+                "autoscalingAlgorithm": "BASIC",
+                "maxNumWorkers": "50",
+                "start": "{{ds}}",
+                "partitionType": "DAY",
             },
-            dag=dag)
+            dag=dag,
+        )
+
 
     .. seealso::
         For more detail on job submission have a look at the reference:
@@ -221,9 +219,9 @@ class DataflowCreateJavaJobOperator(BaseOperator):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:DataflowCreateJavaJobOperator`
 
-    :param jar: The reference to a self executing DataFlow jar (templated).
+    :param jar: The reference to a self executing Dataflow jar (templated).
     :type jar: str
-    :param job_name: The 'jobName' to use when executing the DataFlow job
+    :param job_name: The 'jobName' to use when executing the Dataflow job
         (templated). This ends up being set in the pipeline options, so any entry
         with key ``'jobName'`` in ``options`` will be overwritten.
     :type job_name: str
@@ -317,9 +315,9 @@ class DataflowCreateJavaJobOperator(BaseOperator):
     .. code-block:: python
 
        default_args = {
-           'dataflow_default_options': {
-               'zone': 'europe-west1-d',
-               'stagingLocation': 'gs://my-staging-bucket/staging/'
+           "dataflow_default_options": {
+               "zone": "europe-west1-d",
+               "stagingLocation": "gs://my-staging-bucket/staging/",
            }
        }
 
@@ -330,26 +328,25 @@ class DataflowCreateJavaJobOperator(BaseOperator):
 
     .. code-block:: python
 
-       t1 = DataFlowJavaOperator(
-           task_id='dataflow_example',
-           jar='{{var.value.gcp_dataflow_base}}pipeline/build/libs/pipeline-example-1.0.jar',
+       t1 = DataflowCreateJavaJobOperator(
+           task_id="dataflow_example",
+           jar="{{var.value.gcp_dataflow_base}}pipeline/build/libs/pipeline-example-1.0.jar",
            options={
-               'autoscalingAlgorithm': 'BASIC',
-               'maxNumWorkers': '50',
-               'start': '{{ds}}',
-               'partitionType': 'DAY',
-               'labels': {'foo' : 'bar'}
+               "autoscalingAlgorithm": "BASIC",
+               "maxNumWorkers": "50",
+               "start": "{{ds}}",
+               "partitionType": "DAY",
+               "labels": {"foo": "bar"},
            },
-           gcp_conn_id='airflow-conn-id',
-           dag=my-dag)
+           gcp_conn_id="airflow-conn-id",
+           dag=my - dag,
+       )
 
     """
 
     template_fields = ["options", "jar", "job_name"]
     ui_color = "#0273d4"
 
-    # pylint: disable=too-many-arguments
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -434,21 +431,17 @@ class DataflowCreateJavaJobOperator(BaseOperator):
         with ExitStack() as exit_stack:
             if self.jar.lower().startswith("gs://"):
                 gcs_hook = GCSHook(self.gcp_conn_id, self.delegate_to)
-                tmp_gcs_file = exit_stack.enter_context(  # pylint: disable=no-member
-                    gcs_hook.provide_file(object_url=self.jar)
-                )
+                tmp_gcs_file = exit_stack.enter_context(gcs_hook.provide_file(object_url=self.jar))
                 self.jar = tmp_gcs_file.name
 
                 is_running = False
                 if self.check_if_running != CheckJobRunning.IgnoreJob:
-                    is_running = (
-                        self.dataflow_hook.is_job_dataflow_running(  # pylint: disable=no-value-for-parameter
-                            name=self.job_name,
-                            variables=pipeline_options,
-                        )
+                    is_running = self.dataflow_hook.is_job_dataflow_running(
+                        name=self.job_name,
+                        variables=pipeline_options,
                     )
                     while is_running and self.check_if_running == CheckJobRunning.WaitForRun:
-                        # pylint: disable=no-value-for-parameter
+
                         is_running = self.dataflow_hook.is_job_dataflow_running(
                             name=self.job_name,
                             variables=pipeline_options,
@@ -461,7 +454,7 @@ class DataflowCreateJavaJobOperator(BaseOperator):
                         job_class=self.job_class,
                         process_line_callback=process_line_callback,
                     )
-                    self.dataflow_hook.wait_for_done(  # pylint: disable=no-value-for-parameter
+                    self.dataflow_hook.wait_for_done(
                         job_name=job_name,
                         location=self.location,
                         job_id=self.job_id,
@@ -478,20 +471,20 @@ class DataflowCreateJavaJobOperator(BaseOperator):
             )
 
 
-# pylint: disable=too-many-instance-attributes
 class DataflowTemplatedJobStartOperator(BaseOperator):
     """
-    Start a Templated Cloud DataFlow job. The parameters of the operation
+    Start a Templated Cloud Dataflow job. The parameters of the operation
     will be passed to the job.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:DataflowTemplatedJobStartOperator`
 
-    :param template: The reference to the DataFlow template.
+    :param template: The reference to the Dataflow template.
     :type template: str
-    :param job_name: The 'jobName' to use when executing the DataFlow template
+    :param job_name: The 'jobName' to use when executing the Dataflow template
         (templated).
+    :type job_name: Optional[str]
     :param options: Map of job runtime environment options.
         It will update environment argument if passed.
 
@@ -529,7 +522,7 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
     :type impersonation_chain: Union[str, Sequence[str]]
-    :type environment: Optional, Map of job runtime environment options.
+    :param environment: Optional, Map of job runtime environment options.
 
         .. seealso::
             For more information on possible configurations, look at the API documentation
@@ -584,10 +577,9 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
     .. code-block:: python
 
        default_args = {
-           'dataflow_default_options': {
-               'zone': 'europe-west1-d',
-               'tempLocation': 'gs://my-staging-bucket/staging/',
-               }
+           "dataflow_default_options": {
+               "zone": "europe-west1-d",
+               "tempLocation": "gs://my-staging-bucket/staging/",
            }
        }
 
@@ -597,15 +589,16 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
 
     .. code-block:: python
 
-       t1 = DataflowTemplateOperator(
-           task_id='dataflow_example',
-           template='{{var.value.gcp_dataflow_base}}',
+       t1 = DataflowTemplatedJobStartOperator(
+           task_id="dataflow_example",
+           template="{{var.value.gcp_dataflow_base}}",
            parameters={
-               'inputFile': "gs://bucket/input/my_input.txt",
-               'outputFile': "gs://bucket/output/my_output.txt"
+               "inputFile": "gs://bucket/input/my_input.txt",
+               "outputFile": "gs://bucket/output/my_output.txt",
            },
-           gcp_conn_id='airflow-conn-id',
-           dag=my-dag)
+           gcp_conn_id="airflow-conn-id",
+           dag=my - dag,
+       )
 
     ``template``, ``dataflow_default_options``, ``parameters``, and ``job_name`` are
     templated so you can use variables in them.
@@ -634,8 +627,7 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
     ]
     ui_color = "#0273d4"
 
-    @apply_defaults
-    def __init__(  # pylint: disable=too-many-arguments
+    def __init__(
         self,
         *,
         template: str,
@@ -729,7 +721,7 @@ class DataflowStartFlexTemplateOperator(BaseOperator):
         domain-wide delegation enabled.
     :type delegate_to: str
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
-        instead of canceling during during killing task instance. See:
+        instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
     :type drain_pipeline: bool
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
@@ -773,7 +765,6 @@ class DataflowStartFlexTemplateOperator(BaseOperator):
 
     template_fields = ["body", "location", "project_id", "gcp_conn_id"]
 
-    @apply_defaults
     def __init__(
         self,
         body: Dict,
@@ -849,7 +840,7 @@ class DataflowStartSqlJobOperator(BaseOperator):
         <gcloud beta dataflow sql query>`__
         command reference
 
-    :param options: dict
+    :type options: dict
     :param location: The location of the Dataflow job (for example europe-west1)
     :type location: str
     :param project_id: The ID of the GCP project that owns the job.
@@ -863,7 +854,7 @@ class DataflowStartSqlJobOperator(BaseOperator):
         domain-wide delegation enabled.
     :type delegate_to: str
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
-        instead of canceling during during killing task instance. See:
+        instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
     :type drain_pipeline: bool
     """
@@ -877,7 +868,6 @@ class DataflowStartSqlJobOperator(BaseOperator):
         "gcp_conn_id",
     ]
 
-    @apply_defaults
     def __init__(
         self,
         job_name: str,
@@ -930,7 +920,6 @@ class DataflowStartSqlJobOperator(BaseOperator):
             self.hook.cancel_job(job_id=self.job_id, project_id=self.project_id)
 
 
-# pylint: disable=too-many-instance-attributes
 class DataflowCreatePythonJobOperator(BaseOperator):
     """
     Launching Cloud Dataflow jobs written in python. Note that both
@@ -953,7 +942,7 @@ class DataflowCreatePythonJobOperator(BaseOperator):
     :param py_file: Reference to the python dataflow pipeline file.py, e.g.,
         /some/local/file/path/to/your/python/pipeline/file. (templated)
     :type py_file: str
-    :param job_name: The 'job_name' to use when executing the DataFlow job
+    :param job_name: The 'job_name' to use when executing the Dataflow job
         (templated). This ends up being set in the pipeline options, so any entry
         with key ``'jobName'`` or ``'job_name'`` in ``options`` will be overwritten.
     :type job_name: str
@@ -1006,7 +995,7 @@ class DataflowCreatePythonJobOperator(BaseOperator):
         JOB_STATE_RUNNING state.
     :type poll_sleep: int
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
-        instead of canceling during during killing task instance. See:
+        instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
     :type drain_pipeline: bool
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
@@ -1050,8 +1039,7 @@ class DataflowCreatePythonJobOperator(BaseOperator):
 
     template_fields = ["options", "dataflow_default_options", "job_name", "py_file"]
 
-    @apply_defaults
-    def __init__(  # pylint: disable=too-many-arguments
+    def __init__(
         self,
         *,
         py_file: str,
@@ -1139,9 +1127,7 @@ class DataflowCreatePythonJobOperator(BaseOperator):
         with ExitStack() as exit_stack:
             if self.py_file.lower().startswith("gs://"):
                 gcs_hook = GCSHook(self.gcp_conn_id, self.delegate_to)
-                tmp_gcs_file = exit_stack.enter_context(  # pylint: disable=no-member
-                    gcs_hook.provide_file(object_url=self.py_file)
-                )
+                tmp_gcs_file = exit_stack.enter_context(gcs_hook.provide_file(object_url=self.py_file))
                 self.py_file = tmp_gcs_file.name
 
             self.beam_hook.start_python_pipeline(
@@ -1154,7 +1140,7 @@ class DataflowCreatePythonJobOperator(BaseOperator):
                 process_line_callback=process_line_callback,
             )
 
-            self.dataflow_hook.wait_for_done(  # pylint: disable=no-value-for-parameter
+            self.dataflow_hook.wait_for_done(
                 job_name=job_name,
                 location=self.location,
                 job_id=self.job_id,
